import 'package:example/generated/l10n.dart';
import 'package:example/router/app_route.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wise_util/business/update/app_update_service.dart';
import 'package:wise_util/res/wise_color.dart';
import 'package:wise_util/res/wise_style.dart';
import 'package:wise_util/widget/wise_button.dart';
import 'package:wise_util/widget/wise_loading.dart';

import 'home_controller.dart';

class HomePage extends StatelessWidget {
  HomePage({Key? key}) : super(key: key);

  final controller = Get.find<HomeController>();

  @override
  Widget build(BuildContext context) {
    return GetBuilder<HomeController>(
      assignId: true,
      builder: (controller) {
        return Scaffold(
          appBar: AppBar(
            title: Text("example"),
          ),
          body: SingleChildScrollView(
            child: Container(
              padding: EdgeInsets.all(20),
              width: Get.width,
              height: Get.height,
              color: WiseColor.colorNormalBackground(),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  _buildUtil(),
                  SizedBox(
                    height: 20,
                  ),
                  _buildWidget(),
                  SizedBox(
                    height: 20,
                  ),
                  _buildRes(),
                  SizedBox(
                    height: 20,
                  ),
                  _buildBusiness(),
                ],
              ),
            ),
          ),
        );
      },
    );
  }

  Widget _buildUtil() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Util",
          style: WiseStyle.textStyleSmallTitle(),
        ),
        Wrap(
          spacing: 16,
          children: [
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () async {
                controller.sendHttpRequest();
              },
              child: Text(
                "http request",
                style: TextStyle(color: Colors.white),
              ),
            ),
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () async {
                Get.toNamed(AppRoute.pageFormatter);
              },
              child: Text(
                "formatter",
                style: TextStyle(color: Colors.white),
              ),
            ),
          ],
        ),
      ],
    );
  }

  Widget _buildRes() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Res",
          style: WiseStyle.textStyleSmallTitle(),
        ),
        Wrap(
          spacing: 16,
          children: [
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () {
                controller.switchTheme();
              },
              child: Text(
                "switch theme",
                style: TextStyle(color: Colors.white),
              ),
            ),
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () async {
                Get.toNamed(AppRoute.pageStyle);
              },
              child: Text(
                "text style",
                style: TextStyle(color: Colors.white),
              ),
            ),
            WiseButton.primaryButton("nihao", onPressed: () async {
              await S.load(Locale("zh", "CN"));
              Get.updateLocale(Locale("zh", "CN"));
              print(Get.locale!.toLanguageTag());
            }),
          ],
        ),
      ],
    );
  }

  Widget _buildWidget() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Widget",
          style: WiseStyle.textStyleSmallTitle(),
        ),
        Wrap(
          spacing: 16,
          children: [
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () async {
                WiseLoading.show();
                await Future.delayed(Duration(seconds: 3));
                WiseLoading.dismiss();
              },
              child: Text(
                "showLoading",
                style: TextStyle(color: Colors.white),
              ),
            ),
          ],
        ),
      ],
    );
  }

  Widget _buildBusiness() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Business",
          style: WiseStyle.textStyleSmallTitle(),
        ),
        Wrap(
          spacing: 16,
          children: [
            MaterialButton(
              color: Get.theme.primaryColor,
              onPressed: () async {
                AppUpdateService.checkUpdate();
              },
              child: Text(
                "update",
                style: TextStyle(color: Colors.white),
              ),
            ),
          ],
        ),
      ],
    );
  }
}
