import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class WiseLocalizations {
  final Locale locale;

  WiseLocalizations(this.locale);

  Map<String, WiseString> values = {
    'en': EnWiseString(),
    'zh': ChWiseString(),
    'fr': FrWiseString(),
    'ja': JpWiseString(),
  };

  WiseString? get currentLocalization {
    if (values.containsKey(locale.languageCode)) {
      return values[locale.languageCode];
    }
    return values["en"];
  }

  static const WiseLocalizationsDelegate delegate = WiseLocalizationsDelegate();

  static WiseLocalizations? of(BuildContext context) {
    return Localizations.of(context, WiseLocalizations);
  }
}

class WiseLocalizationsDelegate
    extends LocalizationsDelegate<WiseLocalizations> {
  const WiseLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    return [
      'en',
      'zh',
      'fr',
      'ja',
    ].contains(locale.languageCode);
  }

  @override
  Future<WiseLocalizations> load(Locale locale) {
    return SynchronousFuture<WiseLocalizations>(WiseLocalizations(locale));
  }

  @override
  bool shouldReload(LocalizationsDelegate<WiseLocalizations> old) {
    return false;
  }
}

abstract class WiseString {
  ///Loading加载框默认描述
  late String loading;

  ///Snacker默认标题
  late String error;

  ///网络错误提示
  late String networkError;

  ///应用更新对话框标题
  late String appUpdateDialogTitle;

  ///应用更新对话框取消按钮
  late String appUpdateDialogCancel;

  ///应用更新对话框更新按钮
  late String appUpdateDialogUpdate;
}

class EnWiseString implements WiseString {
  @override
  String loading = "Loading...";

  @override
  String error = "Error";

  @override
  String networkError = "Network error, please check the network";

  @override
  String appUpdateDialogTitle = "Discover new version";

  @override
  String appUpdateDialogCancel = "Later";

  @override
  String appUpdateDialogUpdate = "Update";
}

class ChWiseString implements WiseString {
  @override
  String loading = "加载中...";

  @override
  String error = "错误";

  @override
  String networkError = "网络错误，请检查网络";

  @override
  String appUpdateDialogTitle = "发现新版本";

  @override
  String appUpdateDialogCancel = "稍后";

  @override
  String appUpdateDialogUpdate = "更新";
}

class JpWiseString implements WiseString {
  @override
  String loading = "ロード中...";

  @override
  String error = "エラー";

  @override
  String networkError = "ネットワークエラー、ネットワークを確認してください";

  @override
  String appUpdateDialogTitle = "新しいバージョンの検出";

  @override
  String appUpdateDialogCancel = "あとで";

  @override
  String appUpdateDialogUpdate = "更新";
}

class FrWiseString implements WiseString {
  @override
  String loading = "Chargement en cours...";

  @override
  String error = "Erreur";

  @override
  String networkError = "Erreur réseau, veuillez vérifier le réseau";

  @override
  String appUpdateDialogTitle = "Nouvelle version trouvée";

  @override
  String appUpdateDialogCancel = "Plus tard,";

  @override
  String appUpdateDialogUpdate = "Mise à jour";
}
